@@ -21,6 +21,7 @@ import shutil
 import tempfile
 
 
+from os_net_config import common
 from os_net_config import sriov_config
 from os_net_config.tests import base
 from os_net_config import utils
@@ -34,8 +35,9 @@ class TestSriovConfig(base.TestCase):
         rand = str(int(random.random() * 100000))
 
         tmpdir = tempfile.mkdtemp()
-        self.stub_out('os_net_config.sriov_config._SYS_CLASS_NET', tmpdir)
+        self.stub_out('os_net_config.common.SYS_CLASS_NET', tmpdir)
 
+        common._LOG_FILE = '/tmp/' + rand + 'os_net_config.log'
         sriov_config._UDEV_RULE_FILE = '/tmp/' + rand + 'etc_udev_rules.d'\
             '80-persistent-os-net-config.rules'
         sriov_config._UDEV_LEGACY_RULE_FILE = '/tmp/' + rand + 'etc_udev_'\
@@ -45,16 +47,18 @@ class TestSriovConfig(base.TestCase):
             'rules.d_70-tripleo-reset-sriov.rules'
         sriov_config._ALLOCATE_VFS_FILE = '/tmp/' + rand + 'etc_sysconfig_'\
             'allocate_vfs'
-        sriov_config._SRIOV_CONFIG_FILE = '/tmp/' + rand + 'sriov_config'\
-                                          '.yaml'
+        common.SRIOV_CONFIG_FILE = '/tmp/' + rand + 'sriov_config.yaml'
+        sriov_config._REP_LINK_NAME_FILE = '/tmp/' + rand + 'rep_link.sh'
 
     def tearDown(self):
         super(TestSriovConfig, self).tearDown()
-        if os.path.isfile(sriov_config._SRIOV_CONFIG_FILE):
-            os.remove(sriov_config._SRIOV_CONFIG_FILE)
+        if os.path.isfile(common._LOG_FILE):
+            os.remove(common._LOG_FILE)
+        if os.path.isfile(common.SRIOV_CONFIG_FILE):
+            os.remove(common.SRIOV_CONFIG_FILE)
         if os.path.isfile(sriov_config._IFUP_LOCAL_FILE):
             os.remove(sriov_config._IFUP_LOCAL_FILE)
-        shutil.rmtree(sriov_config._SYS_CLASS_NET)
+        shutil.rmtree(common.SYS_CLASS_NET)
         if os.path.isfile(sriov_config._RESET_SRIOV_RULES_FILE):
             os.remove(sriov_config._RESET_SRIOV_RULES_FILE)
         if os.path.isfile(sriov_config._ALLOCATE_VFS_FILE):
@@ -63,8 +67,8 @@ class TestSriovConfig(base.TestCase):
             os.remove(sriov_config._UDEV_LEGACY_RULE_FILE)
 
     def _write_numvfs(self, ifname, numvfs=0):
-        os.makedirs(sriov_config._get_dev_path(ifname))
-        numvfs_file = sriov_config._get_dev_path(ifname, 'sriov_numvfs')
+        os.makedirs(common.get_dev_path(ifname, '_device'))
+        numvfs_file = common.get_dev_path(ifname, 'sriov_numvfs')
         with open(numvfs_file, 'w') as f:
             f.write(str(numvfs))
 
@@ -243,14 +247,14 @@ class TestSriovConfig(base.TestCase):
                       cleanup_puppet_config_stub)
 
         def _wait_for_vf_creation_stub(pf_name, numvfs):
-            self._save_action('_wait_for_vf_creation_stub')
+            self._save_action('_wait_for_vf_creation')
             return
         self.stub_out('os_net_config.sriov_config._wait_for_vf_creation',
                       _wait_for_vf_creation_stub)
 
         def get_vendor_id_stub(ifname):
             return vendor_id
-        self.stub_out('os_net_config.sriov_config.get_vendor_id',
+        self.stub_out('os_net_config.common.get_vendor_id',
                       get_vendor_id_stub)
 
         def configure_switchdev_stub(pf_name):
@@ -274,6 +278,44 @@ class TestSriovConfig(base.TestCase):
         self.stub_out('os_net_config.sriov_config.set_numvfs',
                       set_numvfs_stub)
 
+        def get_pf_pci_stub(name):
+            pci_address = {"p2p1": "0000:01:01.0",
+                           "p2p2": "0000:01:02.0",
+                           "p2p3": "0000:01:03.0"}
+            return pci_address[name]
+        self.stub_out('os_net_config.sriov_config.get_pf_pci',
+                      get_pf_pci_stub)
+
+        def get_vdpa_vhost_devices_stub():
+            self._save_action('get_vdpa_vhost_devices')
+            return
+        self.stub_out('os_net_config.sriov_config.get_vdpa_vhost_devices',
+                      get_vdpa_vhost_devices_stub)
+
+        def load_kmods_stub(mods):
+            return
+        self.stub_out('os_net_config.sriov_config.load_kmods',
+                      load_kmods_stub)
+
+        def modprobe_stub(*args):
+            out = """vdpa x
+                     vhost_vdpa x
+                  """
+            return out, "hello"
+        self.stub_out('oslo_concurrency.processutils.execute',
+                      modprobe_stub)
+
+        def reload_udev_rules_stub():
+            self._save_action('reload_udev_rules')
+            return
+        self.stub_out('os_net_config.sriov_config.reload_udev_rules',
+                      reload_udev_rules_stub)
+
+    def test_list_kmods(self):
+        self.setUp_pf_stubs()
+        self.assertEqual([], common.list_kmods(["vhost_vdpa", "vdpa"]))
+        self.assertEqual(["test"], common.list_kmods(["test", "vdpa"]))
+
     def test_configure_sriov_pf(self):
         """Test the numvfs setting for SR-IOV PF
 
@@ -291,12 +333,12 @@ class TestSriovConfig(base.TestCase):
             'reload_udev_rules',
             'set_numvfs',
             'get_numvfs',
-            '_wait_for_vf_creation_stub',
+            '_wait_for_vf_creation',
             'get_numvfs',
             'reload_udev_rules',
             'set_numvfs',
             'get_numvfs',
-            '_wait_for_vf_creation_stub',
+            '_wait_for_vf_creation',
             'get_numvfs',
             'udev_monitor_stop',
         ]
@@ -310,8 +352,100 @@ class TestSriovConfig(base.TestCase):
             self._write_numvfs(ifname)
 
         self._action_order = []
-        utils.write_yaml_config(sriov_config._SRIOV_CONFIG_FILE, pf_config)
-        sriov_config.configure_logger(debug=True)
+        utils.write_yaml_config(common.SRIOV_CONFIG_FILE, pf_config)
+        sriov_config.configure_sriov_pf()
+        self.assertEqual(exp_actions, self._action_order)
+        f = open(sriov_config._UDEV_LEGACY_RULE_FILE, 'r')
+        self.assertEqual(exp_udev_content, f.read())
+        self.assertEqual(10, sriov_config.get_numvfs('p2p1'))
+        self.assertEqual(12, sriov_config.get_numvfs('p2p2'))
+
+    def test_configure_sriov_pf_nicpart(self):
+        """Test the udev rules created for legacy mode of SR-IOV PF
+
+        In this case, the VF(s) are already bound/attached
+        """
+
+        self.setUp_pf_stubs()
+
+        exp_udev_content = '# This file is autogenerated by os-net-config\n'\
+            'KERNEL=="p2p2", RUN+="/bin/os-net-config-sriov -n %k:12"\n'
+        exp_actions = [
+            'udev_monitor_setup',
+            'udev_monitor_start',
+            'set_numvfs',
+            'get_numvfs',
+            '_wait_for_vf_creation',
+            'get_numvfs',
+            'reload_udev_rules',
+            'set_numvfs',
+            'get_numvfs',
+            '_wait_for_vf_creation',
+            'get_numvfs',
+            'udev_monitor_stop',
+        ]
+
+        pf_config = [{"device_type": "pf", "name": "p2p1", "numvfs": 10,
+                      "promisc": "on", "link_mode": "legacy"},
+                     {"device_type": "pf", "name": "p2p2", "numvfs": 12,
+                      "promisc": "off", "link_mode": "legacy"},
+                     {"device": {"name": "p2p1", "vfid": 0},
+                      "device_type": "vf", "name": "p2p1v0", "max_tx_rate": 0,
+                      "min_tx_rate": 0, "pci_address": "0000:18:0a.0",
+                      "trust": "on", "spoofcheck": "off"}]
+
+        for ifname in ['p2p1', 'p2p2']:
+            self._write_numvfs(ifname)
+
+        self._action_order = []
+        utils.write_yaml_config(common.SRIOV_CONFIG_FILE, pf_config)
+        sriov_config.configure_sriov_pf()
+        self.assertEqual(exp_actions, self._action_order)
+        f = open(sriov_config._UDEV_LEGACY_RULE_FILE, 'r')
+        self.assertEqual(exp_udev_content, f.read())
+        self.assertEqual(12, sriov_config.get_numvfs('p2p2'))
+
+    def test_configure_sriov_pf_non_nicpart(self):
+        """Test the udev rules created for legacy mode of SR-IOV PF
+
+        In this case, the nic partitioned VF(s) are not attached
+        """
+
+        self.setUp_pf_stubs()
+
+        exp_udev_content = '# This file is autogenerated by os-net-config\n'\
+            'KERNEL=="p2p1", RUN+="/bin/os-net-config-sriov -n %k:10"\n'\
+            'KERNEL=="p2p2", RUN+="/bin/os-net-config-sriov -n %k:12"\n'
+        exp_actions = [
+            'udev_monitor_setup',
+            'udev_monitor_start',
+            'reload_udev_rules',
+            'set_numvfs',
+            'get_numvfs',
+            '_wait_for_vf_creation',
+            'get_numvfs',
+            'reload_udev_rules',
+            'set_numvfs',
+            'get_numvfs',
+            '_wait_for_vf_creation',
+            'get_numvfs',
+            'udev_monitor_stop',
+        ]
+
+        pf_config = [{"device_type": "pf", "name": "p2p1", "numvfs": 10,
+                      "promisc": "on", "link_mode": "legacy"},
+                     {"device_type": "pf", "name": "p2p2", "numvfs": 12,
+                      "promisc": "off", "link_mode": "legacy"},
+                     {"device": {"name": "eno3", "vfid": 1},
+                      "device_type": "vf", "name": "eno3v0", "max_tx_rate": 0,
+                      "min_tx_rate": 0, "pci_address": "0000:18:0e.1",
+                      "trust": "on", "spoofcheck": "off"}]
+
+        for ifname in ['p2p1', 'p2p2']:
+            self._write_numvfs(ifname)
+
+        self._action_order = []
+        utils.write_yaml_config(common.SRIOV_CONFIG_FILE, pf_config)
         sriov_config.configure_sriov_pf()
         self.assertEqual(exp_actions, self._action_order)
         f = open(sriov_config._UDEV_LEGACY_RULE_FILE, 'r')
@@ -324,23 +458,33 @@ class TestSriovConfig(base.TestCase):
 
         """
 
-        self.setUp_pf_stubs(sriov_config.MLNX_VENDOR_ID)
+        self.setUp_pf_stubs(common.MLNX_VENDOR_ID)
 
         exp_actions = [
             'udev_monitor_setup',
             'udev_monitor_start',
+            'get_vdpa_vhost_devices',
             'configure_switchdev',
             'set_numvfs',
             'get_numvfs',
-            '_wait_for_vf_creation_stub',
+            '_wait_for_vf_creation',
             'get_numvfs',
+            'reload_udev_rules',
+            'reload_udev_rules',
+            'reload_udev_rules',
+            'reload_udev_rules',
             'configure_switchdev',
             'set_numvfs',
             'get_numvfs',
-            '_wait_for_vf_creation_stub',
+            '_wait_for_vf_creation',
             'get_numvfs',
+            'reload_udev_rules',
+            'reload_udev_rules',
+            'reload_udev_rules',
+            'trigger_udev_rules',
             'udev_monitor_stop',
         ]
+
         pf_config = [{"device_type": "pf", "name": "p2p1", "numvfs": 10,
                       "vdpa": True, "link_mode": "switchdev"},
                      {"device_type": "pf", "name": "p2p2", "numvfs": 12,
@@ -350,8 +494,7 @@ class TestSriovConfig(base.TestCase):
             self._write_numvfs(ifname)
 
         self._action_order = []
-        utils.write_yaml_config(sriov_config._SRIOV_CONFIG_FILE, pf_config)
-        sriov_config.configure_logger(debug=True)
+        utils.write_yaml_config(common.SRIOV_CONFIG_FILE, pf_config)
         sriov_config.configure_sriov_pf()
         self.assertEqual(exp_actions, self._action_order)
         self.assertEqual(10, sriov_config.get_numvfs('p2p1'))
@@ -470,7 +613,7 @@ class TestSriovConfig(base.TestCase):
         self.stub_out('os_net_config.sriov_config.run_ip_config_cmd',
                       run_ip_config_cmd_stub)
 
-        utils.write_yaml_config(sriov_config._SRIOV_CONFIG_FILE, vf_config)
+        utils.write_yaml_config(common.SRIOV_CONFIG_FILE, vf_config)
         sriov_config.configure_sriov_vf()
 
         for cmd in exp_cmds:
